@@ -14,6 +14,7 @@
 #'
 #' @examples
 #' suppressWarnings(suppressMessages(library(recipes)))
+#' library(modeldata)
 #'
 #' data(biomass)
 #'
@@ -266,7 +267,7 @@ axe_env.step_integer <- function(x, ...) {
 #' @rdname axe-recipe
 #' @export
 axe_env.step_interact <- function(x, ...) {
-  attr(x$terms, ".Environment") <- rlang::empty_env()
+  attr(x$terms, ".Environment") <- rlang::base_env()
   x
 }
 
@@ -655,6 +656,6 @@ axe_env.step_zv <- function(x, ...) {
 #' @rdname axe-recipe
 #' @export
 axe_env.quosure <- function(x, ...) {
-  attr(x, ".Environment") <- rlang::empty_env()
+  attr(x, ".Environment") <- rlang::base_env()
   x
 }
